@@ -886,6 +886,8 @@ class _WebEnginePermissions(QObject):
         QWebEnginePage.Feature.MouseLock: 'content.mouse_lock',
         QWebEnginePage.Feature.DesktopVideoCapture: 'content.desktop_capture',
         QWebEnginePage.Feature.DesktopAudioVideoCapture: 'content.desktop_capture',
+        # 8 == ClipboardReadWrite, new in 6.8
+        QWebEnginePage.Feature(8): 'content.javascript.clipboard',
     }
 
     _messages = {
@@ -897,6 +899,7 @@ class _WebEnginePermissions(QObject):
         QWebEnginePage.Feature.MouseLock: 'hide your mouse pointer',
         QWebEnginePage.Feature.DesktopVideoCapture: 'capture your desktop',
         QWebEnginePage.Feature.DesktopAudioVideoCapture: 'capture your desktop and audio',
+        QWebEnginePage.Feature(8): 'read and write your clipboard',
     }
 
     def __init__(self, tab, parent=None):
@@ -1360,6 +1363,11 @@ class WebEngineTab(browsertab.AbstractTab):
             self._widget.page().toHtml(callback)
 
     def run_js_async(self, code, callback=None, *, world=None):
+        if sip.isdeleted(self._widget):
+            # https://github.com/qutebrowser/qutebrowser/issues/3895
+            log.misc.debug("run_js_async called on deleted tab")
+            return
+
         world_id_type = Union[QWebEngineScript.ScriptWorldId, int]
         if world is None:
             world_id: world_id_type = QWebEngineScript.ScriptWorldId.ApplicationWorld
@@ -1513,7 +1521,7 @@ class WebEngineTab(browsertab.AbstractTab):
                 browsertab.TerminationStatus.crashed,
             QWebEnginePage.RenderProcessTerminationStatus.KilledTerminationStatus:
                 browsertab.TerminationStatus.killed,
-            -1:
+            QWebEnginePage.RenderProcessTerminationStatus(-1):
                 browsertab.TerminationStatus.unknown,
         }
         self.renderer_process_terminated.emit(status_map[status], exitcode)
